<template>
  <div class="app-container">
    <el-card class="box-card" style="width: 100%;margin-top: 15px" shadow="never">
      <!--搜索条件-->
      <div class="filter-container">
        <my-search ref="searchBar" :items="items" @search="fifterForm"></my-search>
      </div>
      <el-row style="margin-top: 8px">
        <el-col>
          <!--列表-->
          <my-table ref="myTable" :filter="filterFrom" :table="table"/>
        </el-col>
      </el-row>
    </el-card>
    <!-- 详情 -->
    <detail v-if="detailShow" :setting="setting" @close="detailShow=false"></detail>
  </div>
</template>

<script>
import MyTable from "@/components/myTable/myTable";
import SettingIplatform from '@/utils/settingIplatform';
import items from './items'
import detail from  '@/views/projectManage/information/detail'
import * as record from '@/api/projectManage/record'
import * as DateFormatter from "@/utils/DateFormatter";
export default {
  name: "index",
  components: { MyTable,detail },
  data() {
    return {
      // 搜索框
      items: items,
      // 搜索条件
      filterFrom: {
        projectName: null,  // 项目总数
        projectCode: null, // 项目编号
        projectCategoryId: null, // 分类
        buildOrgId: null, // 建设单位
        archiveStatus: null, // 类型  0 未归档 1 审核中 2 已归档
        approvalDate: null, // 批复时间
        createTime: null // 创建时间
      },
      detailShow:false,
      setting:{
        id:null,
        title:'详情'
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/p/project/info/record/list', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {// 列控制按钮
            show: false
          },
          generalExport: {// 通用导出按钮
            show: false
          },
          // 自定义工具条按钮
          custom: []
        },
        // 列信息
        columns: [
          {title: '项目名称', field: 'projectName', align: 'left',width: '240px'},
          {title: '编号', field: 'projectCode', align: 'center', width: '180px'},
          {title: '分类', field: 'projectCategoryName', align: 'left', width: '150px'},
          {title: '建设单位', field: 'buildOrgName', align: 'left', width: '200px'},
          {title: '批复时间', field: 'approvalDate', align: 'center', width: '180px',
            formatter: row => {
              return { value: DateFormatter.LongToDate(row.approvalDate) }
            }
          },
          {title: '创建时间', field: 'createTime', align: 'center', width: '180px',
            formatter: row => {
              return { value: DateFormatter.LongToDateTime(row.createTime) }
            }
          },
          {
            title: '状态', field: 'archiveStatus', align: 'center', width: '120px',
            formatter: row => {
              return {value: row.archiveStatus == -1 ? '未归档' : row.archiveStatus == 0 ?'审核中':row.archiveStatus == 1 ?'拒绝归档':'已归档'}
            }
          },
        ],
        // 操作信息
        operation: {
          width: 180,
          align:'center',
          show: true, // 显示操作列
          attr: [
            {
              title: '归档',
              events: row => {
                this.$confirm('确认要归档吗？', {
                  type: 'warning'
                }).then(() => {
                  this.gd(row.id)
                })
              },
              hidden:(row) => {
                return row.archiveStatus == 0||row.archiveStatus == 2
              }
            },
            {
              title: '还原',
              events: row => {
                this.$confirm('确认要还原吗？', {
                  type: 'warning'
                }).then(() => {
                  this.hy(row.id)
                })
              },
              hidden:(row) => {
                return row.archiveStatus !== 2
              }
            },
            {
              title: '详情',
              events: row => {
                this.showDetail(row.id)
              }
            }
          ]
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0
          }
        }
      },
    }
  },
  methods:{
    showDetail(id){
      this.setting = {
        id,
        title:'项目详情'
      }
      this.detailShow = true
    },
    // 查询table列表
    search(pageNum) {
      if (pageNum != undefined) {
        this.$refs.myTable.search(pageNum)
      } else {
        this.$refs.myTable.search()
      }
    },
    fifterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params)
      this.search(1)
    },
    // 归档
    gd(id){
      let data = {id:id}
      record.recordUpd(data).then(res=>{
        this.$message.success('归档成功')
        this.search(1)
      })
    },
    // 还原
    hy(id){
      let data = {id:id}
      record.recordSave(data).then(res=>{
        this.$message.success('还原成功')
        this.search(1)
      })
    },
  }
}
</script>

<style scoped>

</style>
